[![CircleCI](https://circleci.com/gh/facebookresearch/hydra.svg?style=svg&circle-token=af199cd2deca9e70e53776f9ded96284b10687e9)](https://circleci.com/gh/facebookresearch/hydra)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
# Hydra
Hydra is a framework for writing flexible command line applications.

Check the [web site](https://facebookresearch.github.io/hydra/) for more information.

## License
Hydra is licensed under [MIT License](LICENSE).
